/*********************************************************************
 *     Humidity Sensor Module Firmware
 *********************************************************************
 * FileName:        serial.c
 * Dependencies:    none
 * Processor:       Microchip PIC18(L)F14K22
 * Compiler:        Microchip XC8 V1.20
 *
 * SOFTWARE IS PROVIDED "AS IS."  DIGI-KEY EXPRESSLY DISCLAIMS ANY
 * WARRANTY OF ANY KIND, WHETHER EXPRESS OR IMPLIED, INCLUDING BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. IN NO EVENT SHALL DIGI-KEY
 * BE LIABLE FOR ANY INCIDENTAL, SPECIAL, INDIRECT OR CONSEQUENTIAL
 * DAMAGES, LOST PROFITS OR LOST DATA, HARM TO YOUR EQUIPMENT, COST OF
 * PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY OR SERVICES, ANY CLAIMS
 * BY THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF),
 * ANY CLAIMS FOR INDEMNITY OR CONTRIBUTION, OR OTHER SIMILAR COSTS.
 * DIGI-KEY ALSO DISCLAIMS ANY LIABILITY FOR PATENT OR COPYRIGHT
 * INFRINGEMENT.
 *
 * Author: K. Culkins
 * Version: Initial Release v1.00
 * Date: 15 Oct, 2013
 *                
 * Revisions:
 * By              Date            Comment
 * ------------------------------------------------------------------
 *
 *
 ********************************************************************/

/***********************************************************************
 * serial.c
 *
 * Description: Functions relating to the USART, I2C, etc., 
 * serial port initialization.
 ***********************************************************************/
#include <xc.h>
#include <plib.h>

#include "serial.h"
#include "main.h"
/***********************************************************************
 *  Usart_init()
 *
 *  Prototype: (void) Usart_init(void)
 *  Passed arguments: none
 *  Return value: none
 *
 *  Description:  Initialize the USART
 ***********************************************************************/
void Usart_init() {


#ifdef ONEMHZ
  // This configuration is for the PIC clock at 1MHz, Rx interrupts, asynch,
  // 8 bit, 1 stop bit, no parity, 9600 baud
    OpenUSART(USART_TX_INT_OFF &
            USART_RX_INT_OFF &
            USART_ASYNCH_MODE &
            USART_EIGHT_BIT &
            USART_CONT_RX &
            USART_BRGH_HIGH,
            0x19);

    baudUSART(_BAUDCON_BRG16_MASK);

#elif defined(FOURMHZ)
  // This configuration is for the PIC clock at 4MHz, Rx interrupts, asynch,
  // 8 bit, 1 stop bit, no parity, 9600 baud
  OpenUSART(USART_TX_INT_OFF &
            USART_RX_INT_OFF &
            USART_ASYNCH_MODE &
            USART_EIGHT_BIT &
            USART_CONT_RX &
            USART_BRGH_HIGH,
            0x19);

#elif defined(EIGHTMHZ)
  // This configuration is for the PIC clock at 8MHz, Rx interrupts, asynch,
  // 8 bit, 1 stop bit, no parity, 9600 baud
  OpenUSART(USART_TX_INT_OFF &
            USART_RX_INT_OFF &
            USART_ASYNCH_MODE &
            USART_EIGHT_BIT &
            USART_CONT_RX &
            USART_BRGH_HIGH,
            0x33);
#endif
  
return;
}




